@@ -4,19 +4,25 @@ import string
 import requests
 import logging
 from threading import Thread
+import time, datetime
+import random
+
 
 # Import Detection From Stealth
 from .stealth import stealth
 from .get_acrawler import get_acrawler
 from playwright import sync_playwright
 
-try:
-    playwright = sync_playwright().start()
-except Exception as e:
-    raise e
-
+playwright = None
 
 def get_playwright():
+    global playwright
+    if playwright == None:
+        try:
+            playwright = sync_playwright().start()
+        except Exception as e:
+            raise e
+    
     return playwright
 
 
@@ -67,7 +73,7 @@ class browser:
             self.options["executablePath"] = self.executablePath
 
         try:
-            self.browser = playwright.webkit.launch(args=self.args, **self.options)
+            self.browser = get_playwright().webkit.launch(args=self.args, **self.options)
         except Exception as e:
             raise e
             logging.critical(e)
@@ -108,6 +114,47 @@ class browser:
 
         return page
 
+    def base36encode(self, number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
+        """Converts an integer to a base36 string."""
+        base36 = ''
+        sign = ''
+
+        if number < 0:
+            sign = '-'
+            number = -number
+
+        if 0 <= number < len(alphabet):
+            return sign + alphabet[number]
+
+        while number != 0:
+            number, i = divmod(number, len(alphabet))
+            base36 = alphabet[i] + base36
+
+        return sign + base36
+
+    def gen_verifyFp(self):
+        start_time = int(time.time() * 1000)
+        chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"[:]
+        chars_len = len(chars)
+        scenarioTitle = self.base36encode(int(time.time() * 1000))
+        uuid = [0] * 36
+        uuid[8] = '_'
+        uuid[13] = '_'
+        uuid[18] = '_'
+        uuid[23] = '_'
+        uuid[14] = "4"
+        r = None
+        for i in range(36):
+            if uuid[i] == 0:
+                if r == None:
+                    r = 0
+                else:
+                    r = random.random() * chars_len
+                uuid[i] = chars[int(r)]
+        ending = ""
+        for x in uuid:
+            ending += str(x)
+        return "verify_" + scenarioTitle + "_" + ending
     def sign_url(self, **kwargs):
         url = kwargs.get("url", None)
         if url == None:
@@ -120,6 +167,12 @@ class browser:
             for i in range(16)
         )
 
+        if kwargs.get("gen_new_verifyFp", False):
+            verifyFp = self.gen_verifyFp()
+        else:
+            verifyFp = kwargs.get("custom_verifyFp", "verify_khgp4f49_V12d4mRX_MdCO_4Wzt_Ar0k_z4RCQC9pUDpX")
+
+
         if kwargs.get("custom_did", None) != None:
             did = kwargs.get("custom_did", None)
         elif self.did == None:
